<?php
/**
 * @file
 * Deep link - Allow direct access to a specific item of content under certain circumstances - admin.
 */

function deeplink_settings(&$form_state) {
  $form = array();

  $form[DEEPLINK_CONTENT_TYPES] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types'),
    '#description' => t('Select the content types that can be deeplinked to.'),
    '#options' => node_get_types('names'),
    '#default_value' => variable_get(DEEPLINK_CONTENT_TYPES, array()),
  );

  $items = array();
  foreach (controls_get('deeplinkers') as $name => $control) {
    $items[$name] = $control['title'];
  }

  $form[DEEPLINK_ALLOWED_CONTROLS] = array(
    '#type' => 'checkboxes',
    '#title' => t('Deeplink types'),
    '#description' => t('Select which deeplink types are permitted, you have to have at least one. If you deselect one that was previously selected any existing deeplinks already sent out will function until they expire.'),
    '#options' => $items,
    '#default_value' => variable_get(DEEPLINK_ALLOWED_CONTROLS, array()),
    '#required' => TRUE,
  );

  $roles = array();
  $results = db_query(db_rewrite_sql('SELECT r.rid, r.name FROM {role} r WHERE rid>%d ORDER BY name ASC', 'r', 'rid'), DRUPAL_AUTHENTICATED_RID);
  while ($result = db_fetch_object($results)) {
    $roles[$result->rid] = check_plain($result->name);
  }

  $form[DEEPLINK_USER_ROLES] = array(
    '#type' => 'checkboxes',
    '#title' => t('Send to roles'),
    '#description' => t('Select which roles can be sent deeplinks.'),
    '#options' => $roles,
    '#default_value' => variable_get(DEEPLINK_USER_ROLES, array()),
    '#required' => TRUE,
  );

  $form[DEEPLINK_APPROVAL_TIME] = array(
    '#type' => 'select',
    '#title' => t('Available hours'),
    '#description' => t('Select the number of hours the deeplink will be available (by default) after which the deeplink will expire.'),
    '#options' => drupal_map_assoc(array(2,4,8,12,24,36,48,72,96)),
    '#default_value' => variable_get(DEEPLINK_APPROVAL_TIME, DEEPLINK_APPROVAL_TIME_DEFAULT),
  );

  $form[DEEPLINK_DEFAULT_EMAIL_SUBJECT] = array(
    '#type' => 'textfield',
    '#title' => t('Notification email subject'),
    '#description' => t('This is the default email subject to use for notifying individuals about the deeplink. You can insert replacement [tokens] which are listed below, specialised tokens include [end_date] which is when the deeplink ceases to be available. Note that "user" tokens will not work if unregistered users are included in the notifications.'),
    '#default_value' => variable_get(DEEPLINK_DEFAULT_EMAIL_SUBJECT, DEEPLINK_DEFAULT_EMAIL_SUBJECT_CONTENT),
    '#required' => TRUE,
  );

  $form[DEEPLINK_DEFAULT_EMAIL_BODY] = array(
    '#type' => 'textarea',
    '#title' => t('Notification email body'),
    '#description' => t('This is the default email body to use for notifying individuals about the deeplink. You can insert replacement [tokens] which are listed below, specialised tokens include [end_date] which is when the deeplink ceases to be available. Note that "user" tokens will not work if unregistered users are included in the notifications.'),
    '#default_value' => variable_get(DEEPLINK_DEFAULT_EMAIL_BODY, DEEPLINK_DEFAULT_EMAIL_BODY_CONTENT),
    '#required' => TRUE,
  );

  $form['token_help'] = array(
    '#type' => 'fieldset',
    '#title' => t('Tokens'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    array('#value' =>  theme('token_help', 'deeplink')),
    array('#value' =>  theme('token_help', 'global')),
    array('#value' =>  theme('token_help', 'node')),
    array('#value' =>  theme('token_help', 'user')),
  );

  return system_settings_form($form);
}

function deeplink_view(&$account) {
  global $user;
  $user = drupal_clone($user);

  $results = db_query('SELECT dlid FROM {deeplinks} WHERE expires > %d ORDER BY expires ASC', time());
  $deeplinks = array();
  while ($result = db_fetch_object($results)) {
    $deeplink = deeplink_load($result->dlid);
    $control = controls_get('deeplinkers', $deeplink->control);
    if (controls_callback('included', $control, array('data' => $deeplink->data, 'account' => $user))) {
      $deeplinks[$deeplink->dlid] = theme('deeplink', $deeplink);
    }
  }

  $account->content['deeplink'] = array(
    '#title' => t('Available deeplinks'),
    '#description' => t('These are the deeplinks to which you currently have access.'),
    '#type' => 'user_profile_category',
    'deeplink' => array(
      '#value' => empty($deeplinks) ? t('None') : theme('item_list', $deeplinks),
    ),
  );
}
