<?php
/**
 * @file
 * Deep link - Allow direct access to a specific item of content under certain circumstances.
 */

/**
 * Implementation of hook_token_list().
 */
function _deeplink_token_list($type = 'all') {
  $tokens = array();

  if ($type == 'user' || $type == 'all') {
    $tokens['user']['user-firstname'] = t("Tries to breakdown the email address to produce a first name, or just outputs the username.");
    $tokens['user']['user-lastname'] = t("Tries to breakdown the email address to produce a last name, or just outputs the username.");
  }

  if ($type == 'deeplink' || $type == 'all') {
    $tokens['deeplink']['deeplink-url'] = t("The local URL (no domain) for the supplied deeplink object.");
    $tokens['deeplink']['deeplink-url-absolute'] = t("The absolute URL (with domain) for the supplied deeplink object.");
    $tokens['deeplink']['deeplink-link'] = t("The object title wrapped in the local URL (no domain) link for the supplied deeplink object.");
    $tokens['deeplink']['deeplink-link-absolute'] = t("The object title wrapped in the absolute URL (with domain) link for the supplied deeplink object.");
    $tokens['deeplink']['deeplink-expires-small'] = t("The date that the supplied deeplink expires formatted with the small format.");
    $tokens['deeplink']['deeplink-expires-medium'] = t("The date that the supplied deeplink expires formatted with the medium format.");
    $tokens['deeplink']['deeplink-expires-large'] = t("The date that the supplied deeplink expires formatted with the large format.");
    $tokens['deeplink']['deeplink-expires-stamp'] = t("The date that the supplied deeplink expires as a UNIX timestamp.");
    $tokens['deeplink']['deeplink-expires-in'] = t("The days, minutes and hours to when the deeplink expires.");
  }

  return $tokens;
}

/**
 * Implementation of hook_token_values().
 */
function _deeplink_token_values($type, $object = NULL, $options = array()) {
  $values = array();

  if ($type == 'user' && !empty($object)) {
    list($firstname, $lastname) = _deeplink_username($object);
    $values['user-firstname'] = $firstname;
    $values['user-lastname'] = $lastname;
  }

  if ($type == 'deeplink' && !empty($object)) {
    $entity = node_load($object->entity_id);
    $title = 'title';

    $values['deeplink-url'] = url("deeplink/{$object->dlid}");
    $values['deeplink-url-absolute'] = url("deeplink/{$object->dlid}", array('absolute' => TRUE));
    $values['deeplink-link'] = l(check_plain($entity->$title), "deeplink/{$object->dlid}");
    $values['deeplink-link-absolute'] = l(check_plain($entity->$title), "deeplink/{$object->dlid}", array('absolute' => TRUE));
    $values['deeplink-expires-small'] = format_date($object->expires, 'small');
    $values['deeplink-expires-medium'] = format_date($object->expires, 'medium');
    $values['deeplink-expires-large'] = format_date($object->expires, 'large');
    $values['deeplink-expires-stamp'] = $object->expires;
    $values['deeplink-expires-in'] = _deeplink_formatdatediff($object->expires);
  }

  return $values;
}

function _deeplink_formatdatediff($start, $end=null) {
  if (!($start instanceof DateTime)) {
    $start = new DateTime(is_numeric($start)?date(DateTime::ATOM, $start):$start);
  }

  if ($end === null) {
    $end = new DateTime();
  }
  if(!($end instanceof DateTime)) {
    $end = new DateTime(is_numeric($end)?date(DateTime::ATOM, $end):$end);
  }
  if ($start <= $end) {
    return t('expired');
  }
  
  $interval = date_difference($start, $end);  
  if($interval < 60) {
    return t('less than a minute');
  } else {
    return format_interval($interval);
  } 
}

function deeplink_formatinterval($f, $v, $w) {
  return "$f $w" . ($v==1?'':'s');
}

function _deeplink_username($account) {
  list($firstname, $lastname) = array_map('drupal_ucfirst', explode('.', drupal_strtolower($account->name)));
  if (!$firstname || !$lastname) {
    list($firstname, $lastname) = array_map('drupal_ucfirst', explode('.', array_shift(explode('@', drupal_strtolower($account->mail)))));
    if (!$firstname || !$lastname) {
      return array($account->name, $account->name);
    }
  }
  return array($firstname, $lastname);
}
